property_value_alias_bc_short_to_long = {
    "AL": "Arabic_Letter",
    "AN": "Arabic_Number",
    "B": "Paragraph_Separator",
    "BN": "Boundary_Neutral",
    "CS": "Common_Separator",
    "EN": "European_Number",
    "ES": "European_Separator",
    "ET": "European_Terminator",
    "FSI": "First_Strong_Isolate",
    "L": "Left_To_Right",
    "LRE": "Left_To_Right_Embedding",
    "LRI": "Left_To_Right_Isolate",
    "LRO": "Left_To_Right_Override",
    "NSM": "Nonspacing_Mark",
    "ON": "Other_Neutral",
    "PDF": "Pop_Directional_Format",
    "PDI": "Pop_Directional_Isolate",
    "R": "Right_To_Left",
    "RLE": "Right_To_Left_Embedding",
    "RLI": "Right_To_Left_Isolate",
    "RLO": "Right_To_Left_Override",
    "S": "Segment_Separator",
    "WS": "White_Space",
}



property_value_alias_gc_short_to_long = {
    "C": "Other",
    "Cc": "Control",
    "Cf": "Format",
    "Cn": "Unassigned",
    "Co": "Private_Use",
    "Cs": "Surrogate",
    "L": "Letter",
    "LC": "Cased_Letter",
    "Ll": "Lowercase_Letter",
    "Lm": "Modifier_Letter",
    "Lo": "Other_Letter",
    "Lt": "Titlecase_Letter",
    "Lu": "Uppercase_Letter",
    "M": "Mark",
    "Mc": "Spacing_Mark",
    "Me": "Enclosing_Mark",
    "Mn": "Nonspacing_Mark",
    "N": "Number",
    "Nd": "Decimal_Number",
    "Nl": "Letter_Number",
    "No": "Other_Number",
    "P": "Punctuation",
    "Pc": "Connector_Punctuation",
    "Pd": "Dash_Punctuation",
    "Pe": "Close_Punctuation",
    "Pf": "Final_Punctuation",
    "Pi": "Initial_Punctuation",
    "Po": "Other_Punctuation",
    "Ps": "Open_Punctuation",
    "S": "Symbol",
    "Sc": "Currency_Symbol",
    "Sk": "Modifier_Symbol",
    "Sm": "Math_Symbol",
    "So": "Other_Symbol",
    "Z": "Separator",
    "Zl": "Line_Separator",
    "Zp": "Paragraph_Separator",
    "Zs": "Space_Separator",
}



property_value_alias_gc_long_to_short = {
    "Cased_Letter": "LC",
    "Close_Punctuation": "Pe",
    "Connector_Punctuation": "Pc",
    "Control": "Cc",
    "Currency_Symbol": "Sc",
    "Dash_Punctuation": "Pd",
    "Decimal_Number": "Nd",
    "Enclosing_Mark": "Me",
    "Final_Punctuation": "Pf",
    "Format": "Cf",
    "Initial_Punctuation": "Pi",
    "Letter": "L",
    "Letter_Number": "Nl",
    "Line_Separator": "Zl",
    "Lowercase_Letter": "Ll",
    "Mark": "M",
    "Math_Symbol": "Sm",
    "Modifier_Letter": "Lm",
    "Modifier_Symbol": "Sk",
    "Nonspacing_Mark": "Mn",
    "Number": "N",
    "Open_Punctuation": "Ps",
    "Other": "C",
    "Other_Letter": "Lo",
    "Other_Number": "No",
    "Other_Punctuation": "Po",
    "Other_Symbol": "So",
    "Paragraph_Separator": "Zp",
    "Private_Use": "Co",
    "Punctuation": "P",
    "Separator": "Z",
    "Space_Separator": "Zs",
    "Spacing_Mark": "Mc",
    "Surrogate": "Cs",
    "Symbol": "S",
    "Titlecase_Letter": "Lt",
    "Unassigned": "Cn",
    "Uppercase_Letter": "Lu",
}



from typing import Optional

import bisect

from tangled_up_in_unicode.u14_0_0_data.prop_list_to_property import prop_list_to_property
from tangled_up_in_unicode.u14_0_0_data.blocks_to_block_start import blocks_to_block_start
from tangled_up_in_unicode.u14_0_0_data.blocks_to_block_end import blocks_to_block_end
from tangled_up_in_unicode.u14_0_0_data.property_value_alias_age_short_to_long import property_value_alias_age_short_to_long
from tangled_up_in_unicode.u14_0_0_data.property_value_alias_bc_short_to_long import property_value_alias_bc_short_to_long
from tangled_up_in_unicode.u14_0_0_data.property_value_alias_blk_long_to_short import property_value_alias_blk_long_to_short
from tangled_up_in_unicode.u14_0_0_data.property_value_alias_ccc_short_to_long import property_value_alias_ccc_short_to_long
from tangled_up_in_unicode.u14_0_0_data.property_value_alias_ea_short_to_long import property_value_alias_ea_short_to_long
from tangled_up_in_unicode.u14_0_0_data.property_value_alias_gc_short_to_long import property_value_alias_gc_short_to_long
from tangled_up_in_unicode.u14_0_0_data.property_value_alias_sc_long_to_short import property_value_alias_sc_long_to_short
from tangled_up_in_unicode.u14_0_0_data.scripts_to_script_start import scripts_to_script_start
from tangled_up_in_unicode.u14_0_0_data.scripts_to_script_end import scripts_to_script_end
from tangled_up_in_unicode.u14_0_0_data.east_asian_width_to_east_asian_width_start import east_asian_width_to_east_asian_width_start
from tangled_up_in_unicode.u14_0_0_data.east_asian_width_to_east_asian_width_end import east_asian_width_to_east_asian_width_end
from tangled_up_in_unicode.u14_0_0_data.derived_age_to_age_start import derived_age_to_age_start
from tangled_up_in_unicode.u14_0_0_data.derived_age_to_age_end import derived_age_to_age_end
from tangled_up_in_unicode.u14_0_0_data.unicode_data_to_name_start import unicode_data_to_name_start
from tangled_up_in_unicode.u14_0_0_data.unicode_data_to_category_start import unicode_data_to_category_start
from tangled_up_in_unicode.u14_0_0_data.unicode_data_to_category_end import unicode_data_to_category_end
from tangled_up_in_unicode.u14_0_0_data.unicode_data_to_bidirectional_start import unicode_data_to_bidirectional_start
from tangled_up_in_unicode.u14_0_0_data.unicode_data_to_bidirectional_end import unicode_data_to_bidirectional_end
from tangled_up_in_unicode.u14_0_0_data.unicode_data_to_decimal_start import unicode_data_to_decimal_start
from tangled_up_in_unicode.u14_0_0_data.unicode_data_to_digit_start import unicode_data_to_digit_start
from tangled_up_in_unicode.u14_0_0_data.unicode_data_to_numeric_start import unicode_data_to_numeric_start
from tangled_up_in_unicode.u14_0_0_data.unicode_data_to_combining_start import unicode_data_to_combining_start
from tangled_up_in_unicode.u14_0_0_data.unicode_data_to_mirrored_start import unicode_data_to_mirrored_start
from tangled_up_in_unicode.u14_0_0_data.unicode_data_to_mirrored_end import unicode_data_to_mirrored_end
from tangled_up_in_unicode.u14_0_0_data.unicode_data_to_decomposition_start import unicode_data_to_decomposition_start
from tangled_up_in_unicode.u14_0_0_data.unicode_data_to_uppercase_start import unicode_data_to_uppercase_start
from tangled_up_in_unicode.u14_0_0_data.unicode_data_to_lowercase_start import unicode_data_to_lowercase_start
from tangled_up_in_unicode.u14_0_0_data.unicode_data_to_titlecase_start import unicode_data_to_titlecase_start

unidata_version = "14.0.0"


def name(chr: str, default=None) -> str:
    """Returns the name assigned to the character chr as a string.
    If no name is defined, default is returned, or, if not given, ValueError is raised."""
    idx = ord(chr)
    try:
        return unicode_data_to_name_start[idx]
    except KeyError:
        if default is None:
            raise ValueError("no such name")
        else:
            return default


def category(chr: str) -> str:
    """Returns the general category assigned to the character chr as string."""
    idx = ord(chr)
    start_keys = sorted(unicode_data_to_category_start.keys())
    insertion_point = bisect.bisect_left(start_keys, idx)
    if insertion_point == len(start_keys) or start_keys[insertion_point] != idx:
        insertion_point -= 1
    key_start = start_keys[insertion_point]
    result_start = unicode_data_to_category_start[key_start]

    end_keys = sorted(unicode_data_to_category_end.keys())
    insertion_point = bisect.bisect_left(end_keys, idx)
    try:
        key_end = end_keys[insertion_point]
        result_end = unicode_data_to_category_end[key_end]

        if result_end != key_start:
            result_end = result_start
            key_end = key_start
        else:
            result_end = unicode_data_to_category_start[result_end]

        if key_start <= idx <= key_end and result_start == result_end:
            return result_start
        else:
            return "Zzzz"
    except IndexError:
        return "Zzzz"


def bidirectional(chr: str) -> str:
    """Returns the bidirectional class assigned to the character chr as string.
    If no such value is defined, an empty string is returned."""
    idx = ord(chr)
    start_keys = sorted(unicode_data_to_bidirectional_start.keys())
    insertion_point = bisect.bisect_left(start_keys, idx)
    if insertion_point == len(start_keys) or start_keys[insertion_point] != idx:
        insertion_point -= 1
    key_start = start_keys[insertion_point]
    result_start = unicode_data_to_bidirectional_start[key_start]

    end_keys = sorted(unicode_data_to_bidirectional_end.keys())
    insertion_point = bisect.bisect_left(end_keys, idx)
    try:
        key_end = end_keys[insertion_point]
        result_end = unicode_data_to_bidirectional_end[key_end]

        if result_end != key_start:
            result_end = result_start
            key_end = key_start
        else:
            result_end = unicode_data_to_bidirectional_start[result_end]

        if key_start <= idx <= key_end and result_start == result_end:
            return result_start
        else:
            return ""
    except IndexError:
        return ""


def decimal(chr: str, default=None) -> int:
    """Returns the decimal value assigned to the character chr as integer.
    If no such value is defined, default is returned, or, if not given, ValueError is raised."""
    idx = ord(chr)
    try:
        return unicode_data_to_decimal_start[idx]
    except KeyError:
        if default is None:
            raise ValueError("not a decimal")
        else:
            return default


def digit(chr: str, default=None) -> int:
    """Returns the digit value assigned to the character chr as integer.
    If no such value is defined, default is returned, or, if not given, ValueError is raised."""
    idx = ord(chr)
    try:
        return unicode_data_to_digit_start[idx]
    except KeyError:
        if default is None:
            raise ValueError("not a digit")
        else:
            return default


def numeric(chr: str, default=None) -> float:
    """Returns the numeric value assigned to the character chr as float.
    If no such value is defined, default is returned, or, if not given, ValueError is raised."""
    idx = ord(chr)
    try:
        return unicode_data_to_numeric_start[idx]
    except KeyError:
        if default is None:
            raise ValueError("not a numeric character")
        else:
            return default


def combining(chr: str) -> int:
    """Returns the canonical combining class assigned to the character chr as integer.
    Returns 0 if no combining class is defined."""
    idx = ord(chr)
    try:
        return unicode_data_to_combining_start[idx]
    except KeyError:
        return 0


def mirrored(chr: str) -> int:
    """Returns the mirrored property assigned to the character chr as integer.
    Returns 1 if the character has been identified as a "mirrored" character in bidirectional text, 0 otherwise."""
    idx = ord(chr)
    start_keys = sorted(unicode_data_to_mirrored_start.keys())
    insertion_point = bisect.bisect_left(start_keys, idx)
    if insertion_point == len(start_keys) or start_keys[insertion_point] != idx:
        insertion_point -= 1
    key_start = start_keys[insertion_point]
    result_start = unicode_data_to_mirrored_start[key_start]

    end_keys = sorted(unicode_data_to_mirrored_end.keys())
    insertion_point = bisect.bisect_left(end_keys, idx)
    try:
        key_end = end_keys[insertion_point]
        result_end = unicode_data_to_mirrored_end[key_end]

        if result_end != key_start:
            result_end = result_start
            key_end = key_start
        else:
            result_end = unicode_data_to_mirrored_start[result_end]

        if key_start <= idx <= key_end and result_start == result_end:
            return result_start
        else:
            return 0
    except IndexError:
        return 0


def decomposition(chr: str) -> str:
    """Returns the character decomposition mapping assigned to the character chr as string.
    An empty string is returned in case no such mapping is defined."""
    idx = ord(chr)
    try:
        return unicode_data_to_decomposition_start[idx]
    except KeyError:
        return ""


def uppercase(chr: str) -> str:
    """"""
    idx = ord(chr)
    try:
        return unicode_data_to_uppercase_start[idx]
    except KeyError:
        return ""


def lowercase(chr: str) -> str:
    """"""
    idx = ord(chr)
    try:
        return unicode_data_to_lowercase_start[idx]
    except KeyError:
        return ""


def titlecase(chr: str) -> str:
    """"""
    idx = ord(chr)
    try:
        return unicode_data_to_titlecase_start[idx]
    except KeyError:
        return ""


def east_asian_width(chr: str, default=None) -> str:
    """Returns the east asian width assigned to the character chr as string."""
    idx = ord(chr)
    start_keys = sorted(east_asian_width_to_east_asian_width_start.keys())
    insertion_point = bisect.bisect_left(start_keys, idx)
    if insertion_point == len(start_keys) or start_keys[insertion_point] != idx:
        insertion_point -= 1
    key_start = start_keys[insertion_point]
    result_start = east_asian_width_to_east_asian_width_start[key_start]

    end_keys = sorted(east_asian_width_to_east_asian_width_end.keys())
    insertion_point = bisect.bisect_left(end_keys, idx)
    key_end = end_keys[insertion_point]
    result_end = east_asian_width_to_east_asian_width_end[key_end]

    if result_end != key_start:
        result_end = result_start
        key_end = key_start
    else:
        result_end = east_asian_width_to_east_asian_width_start[result_end]

    if key_start <= idx <= key_end and result_start == result_end:
        return result_start
    else:
        if default is None:
            raise ValueError("no east asian width")
        else:
            return default


def age(chr: str) -> str:
    """"""
    idx = ord(chr)
    start_keys = sorted(derived_age_to_age_start.keys())
    insertion_point = bisect.bisect_left(start_keys, idx)
    if insertion_point == len(start_keys) or start_keys[insertion_point] != idx:
        insertion_point -= 1
    key_start = start_keys[insertion_point]
    result_start = derived_age_to_age_start[key_start]

    end_keys = sorted(derived_age_to_age_end.keys())
    insertion_point = bisect.bisect_left(end_keys, idx)
    try:
        key_end = end_keys[insertion_point]
        result_end = derived_age_to_age_end[key_end]

        if result_end != key_start:
            result_end = result_start
            key_end = key_start
        else:
            result_end = derived_age_to_age_start[result_end]

        if key_start <= idx <= key_end and result_start == result_end:
            return result_start
        else:
            return "1.0"
    except IndexError:
        return "1.0"


def block(chr: str) -> str:
    """"""
    idx = ord(chr)
    start_keys = sorted(blocks_to_block_start.keys())
    insertion_point = bisect.bisect_left(start_keys, idx)
    if insertion_point == len(start_keys) or start_keys[insertion_point] != idx:
        insertion_point -= 1
    key_start = start_keys[insertion_point]
    result_start = blocks_to_block_start[key_start]

    end_keys = sorted(blocks_to_block_end.keys())
    insertion_point = bisect.bisect_left(end_keys, idx)
    try:
        key_end = end_keys[insertion_point]
        result_end = blocks_to_block_end[key_end]

        if result_end != key_start:
            result_end = result_start
            key_end = key_start
        else:
            result_end = blocks_to_block_start[result_end]

        if key_start <= idx <= key_end and result_start == result_end:
            return result_start
        else:
            return "Unknown"
    except IndexError:
        return "Unknown"


def script(chr: str) -> str:
    """"""
    idx = ord(chr)
    start_keys = sorted(scripts_to_script_start.keys())
    insertion_point = bisect.bisect_left(start_keys, idx)
    if insertion_point == len(start_keys) or start_keys[insertion_point] != idx:
        insertion_point -= 1
    key_start = start_keys[insertion_point]
    result_start = scripts_to_script_start[key_start]

    end_keys = sorted(scripts_to_script_end.keys())
    insertion_point = bisect.bisect_left(end_keys, idx)
    try:
        key_end = end_keys[insertion_point]
        result_end = scripts_to_script_end[key_end]

        if result_end != key_start:
            result_end = result_start
            key_end = key_start
        else:
            result_end = scripts_to_script_start[result_end]

        if key_start <= idx <= key_end and result_start == result_end:
            return result_start
        else:
            return "Unknown"
    except IndexError:
        return "Unknown"


def prop_list(chr: str) -> list:
    """"""
    idx = ord(chr)
    try:
        return prop_list_to_property[idx]
    except KeyError:
        return set()


def age_long(value: str) -> Optional[str]:
    """"""
    try:
        return property_value_alias_age_short_to_long[value]
    except KeyError:
        return None


def category_long(value: str) -> Optional[str]:
    """"""
    try:
        return property_value_alias_gc_short_to_long[value]
    except KeyError:
        return None


def east_asian_width_long(value: str) -> Optional[str]:
    """"""
    try:
        return property_value_alias_ea_short_to_long[value]
    except KeyError:
        return None


def bidirectional_long(value: str) -> Optional[str]:
    """"""
    try:
        return property_value_alias_bc_short_to_long[value]
    except KeyError:
        return None


def combining_long(value: str) -> Optional[str]:
    """"""
    try:
        return property_value_alias_ccc_short_to_long[value]
    except KeyError:
        return None


def block_abbr(value: str) -> Optional[str]:
    """"""
    try:
        return property_value_alias_blk_long_to_short[value]
    except KeyError:
        return None


def script_abbr(value: str) -> Optional[str]:
    """"""
    try:
        return property_value_alias_sc_long_to_short[value]
    except KeyError:
        return None





from tangled_up_in_unicode.tangled_up_in_unicode_14_0_0 import (
    name,
    decimal,
    digit,
    numeric,
    combining,
    mirrored,
    decomposition,
    category,
    bidirectional,
    east_asian_width,
    script,
    block,
    age,
    unidata_version,
    combining_long,
    category_long,
    bidirectional_long,
    east_asian_width_long,
    script_abbr,
    block_abbr,
    age_long,
    prop_list,
    titlecase,
    lowercase,
    uppercase,
)

__version__ = "0.2.0"

__all__ = [
    "name",
    "decimal",
    "digit",
    "numeric",
    "combining",
    "mirrored",
    "decomposition",
    "category",
    "bidirectional",
    "east_asian_width",
    "script",
    "block",
    "age",
    "unidata_version",
    "combining_long",
    "category_long",
    "bidirectional_long",
    "east_asian_width_long",
    "script_abbr",
    "block_abbr",
    "age_long",
    "prop_list",
    "titlecase",
    "lowercase",
    "uppercase",
    "__version__",
]



property_value_alias_sc_short_to_long = {
    "Adlm": "Adlam",
    "Aghb": "Caucasian_Albanian",
    "Ahom": "Ahom",
    "Arab": "Arabic",
    "Armi": "Imperial_Aramaic",
    "Armn": "Armenian",
    "Avst": "Avestan",
    "Bali": "Balinese",
    "Bamu": "Bamum",
    "Bass": "Bassa_Vah",
    "Batk": "Batak",
    "Beng": "Bengali",
    "Bhks": "Bhaiksuki",
    "Bopo": "Bopomofo",
    "Brah": "Brahmi",
    "Brai": "Braille",
    "Bugi": "Buginese",
    "Buhd": "Buhid",
    "Cakm": "Chakma",
    "Cans": "Canadian_Aboriginal",
    "Cari": "Carian",
    "Cham": "Cham",
    "Cher": "Cherokee",
    "Chrs": "Chorasmian",
    "Copt": "Coptic",
    "Cprt": "Cypriot",
    "Cyrl": "Cyrillic",
    "Deva": "Devanagari",
    "Diak": "Dives_Akuru",
    "Dogr": "Dogra",
    "Dsrt": "Deseret",
    "Dupl": "Duployan",
    "Egyp": "Egyptian_Hieroglyphs",
    "Elba": "Elbasan",
    "Elym": "Elymaic",
    "Ethi": "Ethiopic",
    "Geor": "Georgian",
    "Glag": "Glagolitic",
    "Gong": "Gunjala_Gondi",
    "Gonm": "Masaram_Gondi",
    "Goth": "Gothic",
    "Gran": "Grantha",
    "Grek": "Greek",
    "Gujr": "Gujarati",
    "Guru": "Gurmukhi",
    "Hang": "Hangul",
    "Hani": "Han",
    "Hano": "Hanunoo",
    "Hatr": "Hatran",
    "Hebr": "Hebrew",
    "Hira": "Hiragana",
    "Hluw": "Anatolian_Hieroglyphs",
    "Hmng": "Pahawh_Hmong",
    "Hmnp": "Nyiakeng_Puachue_Hmong",
    "Hrkt": "Katakana_Or_Hiragana",
    "Hung": "Old_Hungarian",
    "Ital": "Old_Italic",
    "Java": "Javanese",
    "Kali": "Kayah_Li",
    "Kana": "Katakana",
    "Khar": "Kharoshthi",
    "Khmr": "Khmer",
    "Khoj": "Khojki",
    "Kits": "Khitan_Small_Script",
    "Knda": "Kannada",
    "Kthi": "Kaithi",
    "Lana": "Tai_Tham",
    "Laoo": "Lao",
    "Latn": "Latin",
    "Lepc": "Lepcha",
    "Limb": "Limbu",
    "Lina": "Linear_A",
    "Linb": "Linear_B",
    "Lisu": "Lisu",
    "Lyci": "Lycian",
    "Lydi": "Lydian",
    "Mahj": "Mahajani",
    "Maka": "Makasar",
    "Mand": "Mandaic",
    "Mani": "Manichaean",
    "Marc": "Marchen",
    "Medf": "Medefaidrin",
    "Mend": "Mende_Kikakui",
    "Merc": "Meroitic_Cursive",
    "Mero": "Meroitic_Hieroglyphs",
    "Mlym": "Malayalam",
    "Modi": "Modi",
    "Mong": "Mongolian",
    "Mroo": "Mro",
    "Mtei": "Meetei_Mayek",
    "Mult": "Multani",
    "Mymr": "Myanmar",
    "Nand": "Nandinagari",
    "Narb": "Old_North_Arabian",
    "Nbat": "Nabataean",
    "Newa": "Newa",
    "Nkoo": "Nko",
    "Nshu": "Nushu",
    "Ogam": "Ogham",
    "Olck": "Ol_Chiki",
    "Orkh": "Old_Turkic",
    "Orya": "Oriya",
    "Osge": "Osage",
    "Osma": "Osmanya",
    "Palm": "Palmyrene",
    "Pauc": "Pau_Cin_Hau",
    "Perm": "Old_Permic",
    "Phag": "Phags_Pa",
    "Phli": "Inscriptional_Pahlavi",
    "Phlp": "Psalter_Pahlavi",
    "Phnx": "Phoenician",
    "Plrd": "Miao",
    "Prti": "Inscriptional_Parthian",
    "Rjng": "Rejang",
    "Rohg": "Hanifi_Rohingya",
    "Runr": "Runic",
    "Samr": "Samaritan",
    "Sarb": "Old_South_Arabian",
    "Saur": "Saurashtra",
    "Sgnw": "SignWriting",
    "Shaw": "Shavian",
    "Shrd": "Sharada",
    "Sidd": "Siddham",
    "Sind": "Khudawadi",
    "Sinh": "Sinhala",
    "Sogd": "Sogdian",
    "Sogo": "Old_Sogdian",
    "Sora": "Sora_Sompeng",
    "Soyo": "Soyombo",
    "Sund": "Sundanese",
    "Sylo": "Syloti_Nagri",
    "Syrc": "Syriac",
    "Tagb": "Tagbanwa",
    "Takr": "Takri",
    "Tale": "Tai_Le",
    "Talu": "New_Tai_Lue",
    "Taml": "Tamil",
    "Tang": "Tangut",
    "Tavt": "Tai_Viet",
    "Telu": "Telugu",
    "Tfng": "Tifinagh",
    "Tglg": "Tagalog",
    "Thaa": "Thaana",
    "Thai": "Thai",
    "Tibt": "Tibetan",
    "Tirh": "Tirhuta",
    "Ugar": "Ugaritic",
    "Vaii": "Vai",
    "Wara": "Warang_Citi",
    "Wcho": "Wancho",
    "Xpeo": "Old_Persian",
    "Xsux": "Cuneiform",
    "Yezi": "Yezidi",
    "Yiii": "Yi",
    "Zanb": "Zanabazar_Square",
    "Zinh": "Inherited",
    "Zyyy": "Common",
    "Zzzz": "Unknown",
}
